package betterquesting.questing;

import betterquesting.api.questing.IQuestLine;
import betterquesting.api.questing.IQuestLineDatabase;
import betterquesting.api2.storage.DBEntry;
import betterquesting.api2.storage.SimpleDatabase;
import betterquesting.api2.utils.QuestLineSorter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import javax.annotation.Nullable;
import net.minecraft.nbt.NBTBase;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
import net.minecraft.util.MathHelper;

/* loaded from: betterquesting_questing.jar:betterquesting/questing/QuestLineDatabase.class */
public final class QuestLineDatabase extends SimpleDatabase<IQuestLine> implements IQuestLineDatabase {
    public static final QuestLineDatabase INSTANCE = new QuestLineDatabase();
    private final List<Integer> lineOrder = new ArrayList();
    private final QuestLineSorter SORTER = new QuestLineSorter(this);

    public /* bridge */ /* synthetic */ NBTBase writeToNBT(NBTBase nBTBase, @Nullable List list) {
        return writeToNBT((NBTTagList) nBTBase, (List<Integer>) list);
    }

    public synchronized int getOrderIndex(int lineID) {
        int order = this.lineOrder.indexOf(Integer.valueOf(lineID));
        if (order >= 0) {
            return order;
        }
        if (getValue(lineID) == null) {
            return -1;
        }
        this.lineOrder.add(Integer.valueOf(lineID));
        return this.lineOrder.size() - 1;
    }

    public void setOrderIndex(int lineID, int index) {
        this.lineOrder.remove(Integer.valueOf(lineID));
        this.lineOrder.add(MathHelper.func_76125_a(index, 0, this.lineOrder.size()), Integer.valueOf(lineID));
    }

    public synchronized List<DBEntry<IQuestLine>> getSortedEntries() {
        List<DBEntry<IQuestLine>> list = new ArrayList<>(getEntries());
        list.sort(this.SORTER);
        return list;
    }

    public IQuestLine createNew(int id) {
        IQuestLine ql = new QuestLine();
        if (id >= 0) {
            add(id, ql);
        }
        return ql;
    }

    public void removeQuest(int questID) {
        for (DBEntry<IQuestLine> ql : getEntries()) {
            ((IQuestLine) ql.getValue()).removeID(questID);
        }
    }

    public NBTTagList writeToNBT(NBTTagList json, @Nullable List<Integer> subset) {
        for (DBEntry<IQuestLine> entry : getEntries()) {
            if (subset == null || subset.contains(Integer.valueOf(entry.getID()))) {
                NBTTagCompound jObj = ((IQuestLine) entry.getValue()).writeToNBT(new NBTTagCompound(), (List) null);
                jObj.func_74768_a("lineID", entry.getID());
                jObj.func_74768_a("order", getOrderIndex(entry.getID()));
                json.func_74742_a(jObj);
            }
        }
        return json;
    }

    public synchronized void readFromNBT(NBTTagList json, boolean merge) {
        if (!merge) {
            reset();
        }
        List<IQuestLine> unassigned = new ArrayList<>();
        HashMap<Integer, Integer> orderMap = new HashMap<>();
        for (int i = 0; i < json.func_74745_c(); i++) {
            NBTTagCompound jql = json.func_150305_b(i);
            int id = jql.func_150297_b("lineID", 99) ? jql.func_74762_e("lineID") : -1;
            int order = jql.func_150297_b("order", 99) ? jql.func_74762_e("order") : -1;
            IQuestLine line = (IQuestLine) getValue(id);
            if (line == null) {
                line = new QuestLine();
            }
            line.readFromNBT(jql, merge);
            if (id >= 0) {
                add(id, line);
            } else {
                unassigned.add(line);
            }
            if (order >= 0) {
                orderMap.put(Integer.valueOf(order), Integer.valueOf(id));
            }
        }
        for (IQuestLine q : unassigned) {
            add(nextID(), q);
        }
        List<Integer> orderKeys = new ArrayList<>(orderMap.keySet());
        Collections.sort(orderKeys);
        this.lineOrder.clear();
        Iterator<Integer> it = orderKeys.iterator();
        while (it.hasNext()) {
            int o = it.next().intValue();
            this.lineOrder.add(orderMap.get(Integer.valueOf(o)));
        }
    }

    public synchronized void reset() {
        super.reset();
        this.lineOrder.clear();
    }
}
